# Generated by roxygen2: do not edit by hand

S3method(broom::augment,RegionResult)
S3method(broom::glance,RegionResult)
S3method(broom::tidy,RegionResult)
export(analyze)
export(bh_fdr)
export(circle_intersection_area)
export(cluster_set_order)
export(compute_pairwise)
export(dice)
export(effective_universe)
export(exclusive_items)
export(fold_enrichment)
export(generate_proportional_svg)
export(geom_venn)
export(hypergeometric_p_value)
export(intersection_items)
export(item_share_distribution)
export(jaccard)
export(list_models)
export(list_samples)
export(load_csv)
export(load_gmt)
export(load_gmx)
export(load_sample)
export(load_tsv)
export(overlap_coefficient)
export(parse_region_expression)
export(render_cluster_heatmap)
export(render_enrichment_bar)
export(render_enrichment_lollipop)
export(render_network)
export(render_share_distribution)
export(render_upset)
export(render_venn_svg)
export(solve_2set)
export(solve_3set)
export(statistics)
export(to_excel_workbook)
export(to_matrix_tsv)
export(to_pdf_report)
export(to_region_summary_tsv)
export(to_statistics_tsv)
export(to_zip_report)
export(union_items)
export(vdl_version)
exportClasses(RegionData)
exportClasses(RegionResult)
exportClasses(StatisticsResult)
exportClasses(SvgImage)
exportClasses(VennDataset)
importFrom(BiocGenerics,union)
importFrom(ComplexUpset,intersection_size)
importFrom(ComplexUpset,upset)
importFrom(ComplexUpset,upset_default_themes)
importFrom(ggplot2,.data)
importFrom(ggplot2,aes)
importFrom(ggplot2,annotation_custom)
importFrom(ggplot2,coord_fixed)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_blank)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,labs)
importFrom(ggplot2,scale_fill_manual)
importFrom(ggplot2,scale_size_continuous)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_void)
importFrom(ggraph,create_layout)
importFrom(ggraph,geom_edge_link)
importFrom(ggraph,geom_node_point)
importFrom(ggraph,geom_node_text)
importFrom(ggraph,ggraph)
importFrom(ggraph,scale_edge_colour_manual)
importFrom(grid,gpar)
importFrom(grid,grid.text)
importFrom(grid,rasterGrob)
importFrom(grid,unit)
importFrom(gridExtra,tableGrob)
importFrom(gridExtra,ttheme_minimal)
importFrom(methods,is)
importFrom(methods,slot)
importFrom(openxlsx,addStyle)
importFrom(openxlsx,addWorksheet)
importFrom(openxlsx,createStyle)
importFrom(openxlsx,createWorkbook)
importFrom(openxlsx,saveWorkbook)
importFrom(openxlsx,writeData)
importFrom(patchwork,plot_annotation)
importFrom(patchwork,wrap_elements)
importFrom(patchwork,wrap_plots)
importFrom(rsvg,rsvg_nativeraster)
importFrom(stats,as.dist)
importFrom(stats,hclust)
importFrom(stats,setNames)
importFrom(tidygraph,tbl_graph)
importFrom(utils,head)
importFrom(xml2,read_xml)
importFrom(xml2,xml_attr)
importFrom(xml2,xml_find_all)
importFrom(xml2,xml_find_first)
importFrom(xml2,xml_set_attr)
importFrom(xml2,xml_set_text)
importFrom(xml2,xml_text)
importFrom(zip,zip)
