% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/tsv-export.R
\name{to_matrix_tsv}
\alias{to_matrix_tsv}
\alias{to_matrix_tsv,RegionResult-method}
\title{Write the Item Matrix TSV}
\usage{
to_matrix_tsv(result, path)

\S4method{to_matrix_tsv}{RegionResult}(result, path)
}
\arguments{
\item{result}{A [`RegionResult-class`].}

\item{path}{Destination file path.}
}
\value{
Invisibly returns `path`.
}
\description{
Mirrors the React webapp's "Export Matrix" button + Python's
`RegionResult.to_matrix_tsv()` byte-for-byte.
}
\details{
Columns: Item, <SetName1>, <SetName2>, ..., Region.
Rows: one per item. Iteration order: mask 1..(2^n - 1); within each mask,
items in `dataset@item_order`.
}
\examples{
ds <- methods::new("VennDataset",
    set_names = c("A", "B"),
    items = list(A = c("x", "y"), B = c("y", "z")),
    item_order = c("x", "y", "z"),
    universe_size = 10L, source_path = NULL, format = "csv")
result <- analyze(ds)
to_matrix_tsv(result, tempfile(fileext = ".tsv"))
\donttest{
result <- analyze(load_sample("dataset_real_cancer_drivers_4"))
to_matrix_tsv(result, tempfile(fileext = ".tsv"))
}
}
