% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/analysis.R
\name{effective_universe}
\alias{effective_universe}
\alias{effective_universe,RegionResult-method}
\title{Effective hypergeometric universe size for a RegionResult}
\usage{
effective_universe(result)

\S4method{effective_universe}{RegionResult}(result)
}
\arguments{
\item{result}{A [`RegionResult-class`].}
}
\value{
Integer, the universe size N.
}
\description{
Returns the universe N consistent with the web tool. Binary CSV/TSV
datasets get `dataset@universe_size` (= csv.rows.length, includes
all-zero rows); aggregated/GMT/GMX datasets fall back to
`length(item_order)` (= |union of items|).
}
\examples{
ds <- methods::new("VennDataset",
    set_names = c("A", "B"),
    items = list(A = c("x", "y"), B = c("y", "z")),
    item_order = c("x", "y", "z"),
    universe_size = 10L, source_path = NULL, format = "csv")
result <- analyze(ds)
effective_universe(result)
\donttest{
ds <- load_sample("dataset_real_cancer_drivers_4")
result <- analyze(ds)
effective_universe(result)   # 20000 for binary cancer drivers sample
}
}
